@@ -34,9 +34,14 @@ define!({
         pub important: Option<Span>,
     }
 
+    pub struct SelectorList {
+        pub span: Span,
+        pub children: Vec<ComplexSelector>,
+    }
+
     pub struct StyleRule {
         pub span: Span,
-        pub selectors: Vec<ComplexSelector>,
+        pub selectors: SelectorList,
         pub block: Block,
     }
 
@@ -422,9 +427,7 @@ define!({
 
     pub struct NestedPageRule {
         pub span: Span,
-
-        pub prelude: Vec<ComplexSelector>,
-
+        pub prelude: SelectorList,
         pub block: PageRuleBlock,
     }
 
